@@ -49,7 +49,7 @@
 
 /* glyph point coordinates */
 typedef struct {
-   int32_t x, y;
+   Fixed x, y;
    } Cd;
 
 typedef struct {
@@ -142,7 +142,7 @@ typedef struct _pthelt {
   int16_t type;
   SegLnkLst *Hs, *Vs;
   bool Hcopy:1, Vcopy:1, isFlex:1, yFlex:1, newCP:1;
-  int unused:9;
+  unsigned int unused:9;
   int16_t count, newhints;
   Fixed x, y, x1, y1, x2, y2, x3, y3;
   } PathElt;
@@ -165,12 +165,6 @@ typedef struct {
   size_t length;    /* number of the entries */
 } ACFontInfo;
 
-typedef struct {
-  char* data;       /* glyph data held in the buffer */
-  size_t length;    /* actual length of the data */
-  size_t capacity;  /* allocated memory size */
-} ACBuffer;
-
 /* global data */
 
 extern ACBuffer* gBezOutput;
@@ -202,10 +196,14 @@ extern AC_REPORTSTEMPTR gAddVStemCB;
 extern AC_REPORTZONEPTR gAddGlyphExtremesCB;
 extern AC_REPORTZONEPTR gAddStemExtremesCB;
 
-void AddStemExtremes(Fixed bot, Fixed top);
-
 extern AC_RETRYPTR gReportRetryCB;
 
+extern void* gAddStemUserData;
+extern void* gAddExtremesUserData;
+extern void* gReportRetryUserData;
+
+void AddStemExtremes(Fixed bot, Fixed top);
+
 #define leftList (gSegLists[0])
 #define rightList (gSegLists[1])
 #define topList (gSegLists[2])
@@ -233,21 +231,21 @@ extern char gGlyphName[MAX_GLYPHNAME_LEN];
 
 /* macros */
 
-#define FixedPosInf INT32_MAX
-#define FixedNegInf INT32_MIN
-#define FixShift (8)
-#define FixInt(i) (((int32_t)(i)) << FixShift)
-#define FixReal(i) ((int32_t)((i) *256.0))
-int32_t FRnd(int32_t x);
-#define FHalfRnd(x) ((int32_t)(((x)+(1<<7)) & ~0xFF))
-#define FracPart(x) ((int32_t)(x) & 0xFF)
-#define FTrunc(x) (((int32_t)(x))>>FixShift)
-#define FIXED2FLOAT(x) (x/256.0)
-
 #define FixOne (0x100)
 #define FixTwo (0x200)
 #define FixHalf (0x80)
 #define FixQuarter (0x40)
+
+#define FIXED_MAX INT32_MAX
+#define FIXED_MIN INT32_MIN
+#define FixInt(i) (((int32_t)(i)) * FixOne)
+#define FixReal(i) ((int32_t)((i) * (float)FixOne))
+int32_t FRnd(int32_t x);
+#define FHalfRnd(x) ((int32_t)(((x)+(1<<7)) & ~0xFF))
+#define FracPart(x) ((int32_t)(x) & 0xFF)
+#define FTrunc(x) (((int32_t)(x)) / FixOne)
+#define FIXED2FLOAT(x) (x / (float)FixOne)
+
 #define FixHalfMul(f) (2*((f) >> 2)) /* DEBUG 8 BIT. Revert this to ((f) >>1) once I am confident that there are not bugs from the update to 8 bits for the Fixed fraction. */
 #define FixTwoMul(f) ((f) << 1)
 #define PSDist(d) ((FixInt(d)))
@@ -260,9 +258,6 @@ int32_t FRnd(int32_t x);
 #define ProdGe0(f0, f1) (!ProdLt0(f0, f1))
 
 #define DEBUG_ROUND(val) { val = ( val >=0 ) ? (2*(val/2)) : (2*((val - 1)/2));}
-#define DEBUG_ROUND4(val) { val = ( val >=0 ) ? (4*(val/4)) : (4*((val - 1)/4));}
-
-#define MAXBUFFLEN 127
 
 /* DEBUG_ROUND is used to force calculations to come out the same as the previous version, where coordinates used 7 bits for the Fixed fraction, rather than the current 8 bits. Once I am confident that there are no bugs in the update, I will remove all occurences of this macro, and accept the differences due to more exact division */
 /* procedures */
@@ -272,7 +267,7 @@ int32_t FRnd(int32_t x);
 void acfixtopflt(Fixed x, float* pf);
 Fixed acpflttofix(float* pf);
 
-unsigned char* Alloc(int32_t sz); /* Sub-allocator */
+void *Alloc(int32_t sz); /* Sub-allocator */
 
 int AddCounterHintGlyphs(char* charlist, char* HintList[]);
 bool FindNameInList(char* nm, char** lst);
@@ -296,8 +291,7 @@ void AddHintPoint(Fixed x0, Fixed y0, Fixed x1, Fixed y1, char ch, PathElt* p0,
 void AddHPair(HintVal* v, char ch);
 void AddVPair(HintVal* v, char ch);
 void XtraHints(PathElt* e);
-bool AutoHintGlyph(const ACFontInfo* fontinfo, const char* srcglyph,
-                    bool extrahint);
+bool AutoHintGlyph(const char* srcglyph, bool extrahint);
 void EvalV(void);
 void EvalH(void);
 void GenVPts(int32_t specialGlyphType);
@@ -329,7 +323,7 @@ void MergeVals(bool vert);
 void MergeFromMainHints(char ch);
 void RoundPathCoords(void);
 void MoveSubpathToEnd(PathElt* e);
-void InitData(const ACFontInfo* fontinfo, int32_t reason);
+void InitData(int32_t reason);
 void InitFix(int32_t reason);
 void InitGen(int32_t reason);
 void InitPick(int32_t reason);
@@ -349,7 +343,6 @@ void ExpectedMoveTo(PathElt* e);
 void ReportMissingClosePath(void);
 void ReportTryFlexNearMiss(Fixed x0, Fixed y0, Fixed x2, Fixed y2);
 void ReportTryFlexError(bool CPflg, Fixed x, Fixed y);
-void AskForSplit(PathElt* e);
 void ReportSplit(PathElt* e);
 void ReportRemFlare(PathElt* e, PathElt* e2, bool hFlg, int32_t i);
 void ReportRemConflict(PathElt* e);
@@ -377,9 +370,9 @@ void ReportMergeVVal(Fixed l0, Fixed r0, Fixed l1, Fixed r1, Fixed v0, Fixed s0,
                      Fixed v1, Fixed s1);
 void ReportPruneHVal(HintVal* val, HintVal* v, int32_t i);
 void ReportPruneVVal(HintVal* val, HintVal* v, int32_t i);
-void InitShuffleSubpaths(void);
-void MarkLinks(HintVal* vL, bool hFlg);
-void DoShuffleSubpaths(void);
+unsigned char* InitShuffleSubpaths(void);
+void MarkLinks(HintVal* vL, bool hFlg, unsigned char* links);
+void DoShuffleSubpaths(unsigned char* links);
 void CopyMainH(void);
 void CopyMainV(void);
 void RMovePoint(Fixed dx, Fixed dy, int32_t whichcp, PathElt* e);
@@ -388,19 +381,18 @@ void AddVSegment(Fixed from, Fixed to, Fixed loc, PathElt* p1, PathElt* p2,
 void AddHSegment(Fixed from, Fixed to, Fixed loc, PathElt* p1, PathElt* p2,
                  int32_t typ, int32_t i);
 void Delete(PathElt* e);
-bool ReadGlyph(const ACFontInfo* fontinfo, const char* srcglyph,
-               bool forBlendData, bool readHints);
+bool ReadGlyph(const char* srcglyph, bool forBlendData, bool readHints);
 double FixToDbl(Fixed f);
 bool CompareValues(HintVal* val1, HintVal* val2, int32_t factor,
                    int32_t ghstshift);
-void SaveFile(const ACFontInfo* fontinfo);
+void SaveFile(void);
 void CheckForMultiMoveTo(void);
 #define STARTUP (0)
 #define RESTART (1)
 
 void ListHintInfo(void);
 
-void InitAll(const ACFontInfo* fontinfo, int32_t reason);
+void InitAll(int32_t reason);
 
 void AddVStem(Fixed right, Fixed left, bool curved);
 void AddHStem(Fixed top, Fixed bottom, bool curved);
@@ -410,8 +402,7 @@ void AddGlyphExtremes(Fixed bot, Fixed top);
 bool AutoHint(const ACFontInfo* fontinfo, const char* srcbezdata,
               bool extrahint, bool changeGlyph, bool roundCoords);
 
-bool MergeGlyphPaths(const ACFontInfo* fontinfo, const char** srcglyphs,
-                    int nmasters, const char** masters, char** outbuffers,
-                    size_t* outlengths);
+bool MergeGlyphPaths(const char** srcglyphs, int nmasters,
+                     const char** masters, ACBuffer** outbuffers);
 
 #endif /* AC_AC_H_ */
