@@ -17,18 +17,16 @@
 #include "ac.h"
 #include "basic.h"
 
-#define		ACOPTIONAL		1
-#define		MANDATORY		0
+#define		OPTIONAL		true
+#define		MANDATORY		false
 
 /* Default value used by PS interpreter and Adobe's fonts to extend the range
  * of alignment zones. */
 #define DEFAULTBLUEFUZZ FixOne
 
+ACFontInfo* ParseFontInfo(const char* data);
+void FreeFontInfo(ACFontInfo* fontinfo);
+
 bool ReadFontInfo(const ACFontInfo* fontinfo);
 
-/* Looks up the value of the specified keyword in the fontinfo
-   file.  If the keyword doesn't exist and this is an optional
-   key, returns a NULL.	 Otherwise, returns the value string. */
-char* GetFontInfo(const ACFontInfo*, char*, bool);
-
 #endif /* AC_FONTINFO_H_ */
