@@ -7,6 +7,8 @@
  * This license is available at: http://opensource.org/licenses/Apache-2.0.
  */
 
+#include "psautohint.h"
+
 #include "basic.h"
 
 #ifndef BF_LOGGING_H_
@@ -18,13 +20,17 @@
 #define FATALERROR 2
 
 /* defines for LogMsg level param */
-#define INFO 0
-#define WARNING 1
-#define LOGERROR 2
+#define LOGDEBUG  AC_LogDebug
+#define INFO      AC_LogInfo
+#define WARNING   AC_LogWarning
+#define LOGERROR  AC_LogError
 
 /* maximum message length */
 #define MAXMSGLEN 500
 
+/* global log function which is supplied by the following */
+extern AC_REPORTFUNCPTR gLibReportCB;
+
 void LogMsg(int16_t, int16_t, char *, ...);
 
 void set_errorproc( int (*)(int16_t) );
