@@ -17,11 +17,11 @@
  * band is expanded by CLSMRG in each direction
  */
 static bool
-CloseElements(PPathElt e1, PPathElt e2, Fixed loc1, Fixed loc2, bool vert)
+CloseElements(PathElt* e1, PathElt* e2, Fixed loc1, Fixed loc2, bool vert)
 {
     Fixed tmp;
     Fixed x, y;
-    PPathElt e;
+    PathElt* e;
     if (e1 == e2)
         return true;
     if (loc1 < loc2) {
@@ -55,11 +55,13 @@ CloseElements(PPathElt e1, PPathElt e2, Fixed loc1, Fixed loc2, bool vert)
 }
 
 bool
-CloseSegs(PClrSeg s1, PClrSeg s2, bool vert)
+CloseSegs(HintSeg* s1, HintSeg* s2, bool vert)
 {
     /* true if the elements for these segs are "close" in the path */
-    PPathElt e1, e2;
+    PathElt *e1, *e2;
     Fixed loc1, loc2;
+    if ((s1 == NULL) || (s2 == NULL))
+        return false;
     if (s1 == s2)
         return true;
     e1 = s1->sElt;
@@ -81,7 +83,7 @@ DoPrune(void)
     that to be the head of the list. Then remove from the list
     any subsequent element for which 'pruned' is true.
     */
-    PClrVal vL = gValList, vPrv;
+    HintVal *vL = gValList, *vPrv;
     while (vL != NULL && vL->pruned)
         vL = vL->vNxt;
     gValList = vL;
@@ -99,8 +101,8 @@ DoPrune(void)
     }
 }
 
-static PClrVal
-PruneOne(PClrVal sLst, bool hFlg, PClrVal sL, int32_t i)
+static HintVal*
+PruneOne(HintVal* sLst, bool hFlg, HintVal* sL, int32_t i)
 {
     /* Simply set the 'pruned' field to True for sLst. */
     if (hFlg)
@@ -113,33 +115,56 @@ PruneOne(PClrVal sLst, bool hFlg, PClrVal sL, int32_t i)
 
 #define PRNDIST (PSDist(10))
 #define PRNFCTR (3)
-
-#define PruneLt(val, v)                                                        \
-    (((v) < (FixedPosInf / 10) && (val) < (FixedPosInf / PRNFCTR))             \
-       ? ((val)*PRNFCTR < (v)*10)                                              \
-       : ((val) / 10 < (v) / PRNFCTR))
-#define PruneLe(val, v)                                                        \
-    (((val) < (FixedPosInf / PRNFCTR)) ? ((v) <= (val)*PRNFCTR)                \
-                                       : ((v) / PRNFCTR <= (val)))
-#define PruneGt(val, v)                                                        \
-    (((val) < (FixedPosInf / PRNFCTR)) ? ((v) > (val)*PRNFCTR)                 \
-                                       : ((v) / PRNFCTR > (val)))
 #define MUCHFCTR (50)
-#define PruneMuchGt(val, v)                                                    \
-    (((val) < (FixedPosInf / MUCHFCTR)) ? ((v) > (val)*MUCHFCTR)               \
-                                        : ((v) / MUCHFCTR > (val)))
 #define VERYMUCHFCTR (100)
-#define PruneVeryMuchGt(val, v)                                                \
-    (((val) < (FixedPosInf / VERYMUCHFCTR)) ? ((v) > (val)*VERYMUCHFCTR)       \
-                                            : ((v) / VERYMUCHFCTR > (val)))
+
+static bool
+PruneLt(Fixed val, Fixed v)
+{
+    if (v < (FIXED_MAX / 10) && val < (FIXED_MAX / PRNFCTR))
+        return (val * PRNFCTR) < (v * 10);
+    return (val / 10) < (v / PRNFCTR);
+}
+
+static bool
+PruneLe(Fixed val, Fixed v)
+{
+    if (val < (FIXED_MAX / PRNFCTR))
+        return v <= (val * PRNFCTR);
+    return (v / PRNFCTR) <= val;
+}
+
+static bool
+PruneGt(Fixed val, Fixed v)
+{
+    if (val < (FIXED_MAX / PRNFCTR))
+        return v > (val * PRNFCTR);
+    return (v / PRNFCTR) > val;
+}
+
+static bool
+PruneMuchGt(Fixed val, Fixed v)
+{
+    if (val < (FIXED_MAX / MUCHFCTR))
+        return v > (val * MUCHFCTR);
+    return (v / MUCHFCTR) > val;
+}
+
+static bool
+PruneVeryMuchGt(Fixed val, Fixed v)
+{
+    if (val < (FIXED_MAX / VERYMUCHFCTR))
+        return v > (val * VERYMUCHFCTR);
+    return (v / VERYMUCHFCTR) > val;
+}
 
 /* The changes made here and in PruneHVals are to fix a bug in
- MinisterLight/E where the top left point was not getting colored. */
+ MinisterLight/E where the top left point was not getting hinted. */
 void
 PruneVVals(void)
 {
-    PClrVal sLst, sL;
-    PClrSeg seg1, seg2, sg1, sg2;
+    HintVal *sLst, *sL;
+    HintSeg *seg1, *seg2, *sg1, *sg2;
     Fixed lft, rht, l, r, prndist;
     Fixed val, v;
     bool flg, otherLft, otherRht;
@@ -214,8 +239,8 @@ PruneVVals(void)
 void
 PruneHVals(void)
 {
-    PClrVal sLst, sL;
-    PClrSeg seg1, seg2, sg1, sg2;
+    HintVal *sLst, *sL;
+    HintSeg *seg1, *seg2, *sg1, *sg2;
     Fixed bot, top, t, b;
     Fixed val, v, prndist;
     bool flg, otherTop, otherBot, topInBlue, botInBlue, ghst;
@@ -255,20 +280,17 @@ PruneHVals(void)
 
             if (/* Prune sLst if the following are all true */
                 PruneGt(val, v) && /*  v is more than 3* val */
-
-                ((gYgoesUp && top + prndist >= t && bot - prndist <= b) ||
-                 (!gYgoesUp && top - prndist <= t &&
-                  bot + prndist >=
-                    b)) && /* The sL hint is within the sLst hint */
+                (top - prndist <= t &&
+                 bot + prndist >=
+                   b) && /* The sL hint is within the sLst hint */
 
                 (val < FixInt(100) && PruneMuchGt(val, v)
                    ? (CloseSegs(seg1, sg1, false) ||
                       CloseSegs(seg2, sg2, false))
                    : (CloseSegs(seg1, sg1, false) &&
-                      CloseSegs(seg2, sg2,
-                                false))) && /* val is less than 100, and the
-                                               segments are close to each
-                                               other.*/
+                      CloseSegs(seg2, sg2, false))) && /* val is less than 100,
+                                                          and the segments are
+                                                          close to each other.*/
 
                 (val < Fix16 ||
                  /* needs to be greater than FixOne << 3 for
@@ -280,7 +302,7 @@ PruneHVals(void)
                                                 the value is the same as SL,
                                                 and not in a blue zone. */
 
-                ) {
+            ) {
                 sLst = PruneOne(sLst, true, sL, 5);
                 flg = false;
                 break;
@@ -295,7 +317,7 @@ PruneHVals(void)
                 if (PruneGt(val, v) && /* If v is more than 3* val) */
                     !topInBlue && seg2->sType == sBEND &&
                     CloseSegs(seg1, sg1, false) /* and the tops are close */
-                    ) {
+                ) {
                     sLst = PruneOne(sLst, true, sL, 6);
                     flg = false;
                     break;
@@ -345,11 +367,11 @@ PruneHVals(void)
 }
 
 static void
-FindBestVals(PClrVal vL)
+FindBestVals(HintVal* vL)
 {
     Fixed bV, bS;
     Fixed t, b;
-    PClrVal vL2, vPrv, bstV;
+    HintVal *vL2, *vPrv, *bstV;
     for (; vL != NULL; vL = vL->vNxt) {
         if (vL->vBst != NULL)
             continue; /* already assigned */
@@ -380,24 +402,22 @@ FindBestVals(PClrVal vL)
 }
 
 /* The following changes were made to fix a problem in Ryumin-Light and
- possibly other fonts as well.  The old version causes bogus coloring
- and extra newcolors. */
+ possibly other fonts as well.  The old version causes bogus hinting
+ and extra newhints. */
 static void
-ReplaceVals(Fixed oldB, Fixed oldT, Fixed newB, Fixed newT, PClrVal newBst,
+ReplaceVals(Fixed oldB, Fixed oldT, Fixed newB, Fixed newT, HintVal* newBst,
             bool vert)
 {
-    PClrVal vL;
+    HintVal* vL;
     for (vL = gValList; vL != NULL; vL = vL->vNxt) {
         if (vL->vLoc1 != oldB || vL->vLoc2 != oldT || vL->merge)
             continue;
-        if (gShowClrInfo) {
-            if (vert)
-                ReportMergeVVal(oldB, oldT, newB, newT, vL->vVal, vL->vSpc,
-                                newBst->vVal, newBst->vSpc);
-            else
-                ReportMergeHVal(oldB, oldT, newB, newT, vL->vVal, vL->vSpc,
-                                newBst->vVal, newBst->vSpc);
-        }
+        if (vert)
+            ReportMergeVVal(oldB, oldT, newB, newT, vL->vVal, vL->vSpc,
+                            newBst->vVal, newBst->vSpc);
+        else
+            ReportMergeHVal(oldB, oldT, newB, newT, vL->vVal, vL->vSpc,
+                            newBst->vVal, newBst->vSpc);
         vL->vLoc1 = newB;
         vL->vLoc2 = newT;
         vL->vVal = newBst->vVal;
@@ -410,9 +430,9 @@ ReplaceVals(Fixed oldB, Fixed oldT, Fixed newB, Fixed newT, PClrVal newBst,
 void
 MergeVals(bool vert)
 {
-    PClrVal vLst, vL;
-    PClrVal bstV, bV;
-    PClrSeg seg1, seg2, sg1, sg2;
+    HintVal *vLst, *vL;
+    HintVal *bstV, *bV;
+    HintSeg *seg1, *seg2, *sg1, *sg2;
     Fixed bot, top, b, t;
     Fixed val, v, spc, s;
     bool ghst;
@@ -430,6 +450,7 @@ MergeVals(bool vert)
         vL = NULL;
         while (vLst != NULL) {
             if (vLst->merge) {
+                /* do nothing */
             } else if (vL == NULL ||
                        CompareValues(vLst->vBst, vL->vBst, SFACTOR, 0))
                 vL = vLst;
@@ -472,10 +493,10 @@ MergeVals(bool vert)
                   (b == bot || !InBlueBand(bot, gLenBotBands, gBotBands))))) {
                 if (s == spc && val == v && !vert) {
                     if (InBlueBand(t, gLenTopBands, gTopBands)) {
-                        if ((gYgoesUp && t > top) || (!gYgoesUp && t < top))
+                        if (t < top)
                             goto replace;
                     } else if (InBlueBand(b, gLenBotBands, gBotBands)) {
-                        if ((gYgoesUp && b < bot) || (!gYgoesUp && b > bot))
+                        if (b > bot)
                             goto replace;
                     }
                 } else
