@@ -455,7 +455,7 @@ def get_bez_glyphs(options, font, glyph_list):
     return glyphs
 
 
-def get_fontinfo_list(options, font, path, glyph_list, is_var):
+def get_fontinfo_list(options, font, glyph_list, is_var=False):
 
     # Check counter glyphs, if any.
     counter_glyphs = options.hCounterGlyphs + options.vCounterGlyphs
@@ -471,13 +471,12 @@ def get_fontinfo_list(options, font, path, glyph_list, is_var):
     # or CFF2 fonts, as these have FDArrays, can can truly support
     # different Font.Dict.Private Dicts for different groups of glyphs.
     if font.hasFDArray():
-        return get_fontinfo_list_withFDArray(options, font, path,
-                                             glyph_list, is_var)
+        return get_fontinfo_list_withFDArray(options, font, glyph_list, is_var)
     else:
-        return get_fontinfo_list_withFontInfo(options, font, path, glyph_list)
+        return get_fontinfo_list_withFontInfo(options, font, glyph_list)
 
 
-def get_fontinfo_list_withFDArray(options, font, path, glyph_list, is_var):
+def get_fontinfo_list_withFDArray(options, font, glyph_list, is_var=False):
     lastFDIndex = None
     fontinfo_list = {}
     for name in glyph_list:
@@ -497,7 +496,7 @@ def get_fontinfo_list_withFDArray(options, font, path, glyph_list, is_var):
     return fontinfo_list
 
 
-def get_fontinfo_list_withFontInfo(options, font, path, glyph_list):
+def get_fontinfo_list_withFontInfo(options, font, glyph_list):
     # Build alignment zone string
     if options.printDefaultFDDict:
         print("Showing default FDDict Values:")
@@ -740,8 +739,7 @@ def hint_vf_font(options, font_path, out_path):
     aliases = options.nameAliases
     glyph_names = get_glyph_list(options, font, font_path)
     log.info("Hinting font %s. Start time: %s.", font_path, time.asctime())
-    fontinfo_list = get_fontinfo_list(options, font, font_path,
-                                      glyph_names, True)
+    fontinfo_list = get_fontinfo_list(options, font, glyph_names, True)
     hinted_glyphs = set()
 
     for name in glyph_names:
@@ -793,8 +791,7 @@ def hint_with_reference_font(options, fonts, paths, outpaths):
     # fonts have the same glyph set, glyph dict and in general are
     # compatible. If not bad things will happen.
     glyph_names = get_glyph_list(options, fonts[0], paths[0])
-    fontinfo_list = get_fontinfo_list(options, fonts[0], paths[0],
-                                      glyph_names, False)
+    fontinfo_list = get_fontinfo_list(options, fonts[0], glyph_names)
 
     glyphs = []
     for i, font in enumerate(fonts):
@@ -821,8 +818,7 @@ def hint_regular_fonts(options, fonts, paths, outpaths):
         outpath = outpaths[i]
 
         glyph_names = get_glyph_list(options, font, path)
-        fontinfo_list = get_fontinfo_list(options, font, path, glyph_names,
-                                          False)
+        fontinfo_list = get_fontinfo_list(options, font, glyph_names)
 
         log.info("Hinting font %s. Start time: %s.", path, time.asctime())
 
