@@ -110,8 +110,6 @@ tools stripped out the _hintFormat1_ hint data as invalid elements.
 
 """
 
-from __future__ import print_function, absolute_import
-
 import ast
 import hashlib
 import logging
@@ -120,12 +118,12 @@ import re
 import shutil
 
 from collections import OrderedDict
+from types import SimpleNamespace
 
-from fontTools.misc.py23 import SimpleNamespace, open
 from fontTools.pens.basePen import BasePen
-from ufoLib import (UFOReader, UFOWriter, DATA_DIRNAME, DEFAULT_GLYPHS_DIRNAME,
-                    DEFAULT_LAYER_NAME)
-from ufoLib.pointPen import AbstractPointPen
+from fontTools.pens.pointPen import AbstractPointPen
+from fontTools.ufoLib import UFOReader, UFOWriter
+from fontTools.ufoLib.errors import UFOLibError
 
 from . import fdTools, FontParseError
 
@@ -321,10 +319,12 @@ Example from "B" in SourceCodePro-Regular
 """
 
 # UFO names
+PUBLIC_GLYPH_ORDER = "public.glyphOrder"
+
 ADOBE_DOMAIN_PREFIX = "com.adobe.type"
 
-PROCESSED_LAYER_NAME = "AFDKO ProcessedGlyphs"
-PROCESSED_GLYPHS_DIRNAME = "glyphs.%s.processedGlyphs" % ADOBE_DOMAIN_PREFIX
+PROCESSED_LAYER_NAME = "%s.processedglyphs" % ADOBE_DOMAIN_PREFIX
+PROCESSED_GLYPHS_DIRNAME = "glyphs.%s" % PROCESSED_LAYER_NAME
 
 HASHMAP_NAME = "%s.processedHashMap" % ADOBE_DOMAIN_PREFIX
 HASHMAP_VERSION_NAME = "hashMapVersion"
@@ -382,19 +382,21 @@ class UFOFontData:
     def isCID():
         return False
 
+    @staticmethod
+    def hasFDArray():
+        return False
+
     def convertToBez(self, name, read_hints, round_coords, doAll=False):
         # We do not yet support reading hints, so read_hints is ignored.
         width, bez, skip = self._get_or_skip_glyph(name, round_coords, doAll)
         if skip:
-            return None, width
+            return None
 
         bezString = "\n".join(bez)
         bezString = "\n".join(["% " + name, "sc", bezString, "ed", ""])
-        return bezString, width
+        return bezString
 
-    def updateFromBez(self, bezData, name, width):
-        # For UFO font, we don't use the width parameter:
-        # it is carried over from the input glif file.
+    def updateFromBez(self, bezData, name, mm_hint_info=None):
         layer = None
         if name in self.processedLayerGlyphMap:
             layer = PROCESSED_LAYER_NAME
@@ -402,6 +404,8 @@ class UFOFontData:
 
         glyph = BezGlyph(bezData)
         glyphset.readGlyph(name, glyph)
+        if hasattr(glyph, 'width'):
+            glyph.width = norm_float(glyph.width)
         self.newGlyphMap[name] = glyph
 
         # updateFromBez is called only if the glyph has been autohinted which
@@ -423,22 +427,25 @@ class UFOFontData:
                 shutil.rmtree(path)
             shutil.copytree(self.path, path)
 
-        writer = UFOWriter(path, self._reader.formatVersion, validate=False)
-
-        if self.hashMapChanged:
-            self.writeHashMap(writer)
-        self.hashMapChanged = False
+        writer = UFOWriter(path,
+                           self._reader.formatVersionTuple,
+                           validate=False)
 
         layer = PROCESSED_LAYER_NAME
         if self.writeToDefaultLayer:
             layer = None
 
         # Write layer contents.
-        layers = {DEFAULT_LAYER_NAME: DEFAULT_GLYPHS_DIRNAME}
-        if self.processedLayerGlyphMap or not self.writeToDefaultLayer:
+        layers = writer.layerContents.copy()
+        if self.writeToDefaultLayer and PROCESSED_LAYER_NAME in layers:
+            # Delete processed glyphs directory
+            writer.deleteGlyphSet(PROCESSED_LAYER_NAME)
+            # Remove entry from 'layercontents.plist' file
+            del layers[PROCESSED_LAYER_NAME]
+        elif self.processedLayerGlyphMap or not self.writeToDefaultLayer:
             layers[PROCESSED_LAYER_NAME] = PROCESSED_GLYPHS_DIRNAME
         writer.layerContents.update(layers)
-        writer.writeLayerContents([DEFAULT_LAYER_NAME, PROCESSED_LAYER_NAME])
+        writer.writeLayerContents()
 
         # Write glyphs.
         glyphset = writer.getGlyphSet(layer, defaultLayer=layer is None)
@@ -447,15 +454,24 @@ class UFOFontData:
             if not self.writeToDefaultLayer and \
                     name in self.processedLayerGlyphMap:
                 filename = self.processedLayerGlyphMap[name]
+            # Recalculate glyph hashes
+            if self.writeToDefaultLayer:
+                self.recalcHashEntry(name, glyph)
             glyphset.contents[name] = filename
             glyphset.writeGlyph(name, glyph, glyph.drawPoints)
         glyphset.writeContents()
 
+        # Write hashmap
+        if self.hashMapChanged:
+            self.writeHashMap(writer)
+
     @property
     def hashMap(self):
         if self._hashmap is None:
-            data = self._reader.readBytesFromPath(
-                os.path.join(DATA_DIRNAME, HASHMAP_NAME))
+            try:
+                data = self._reader.readData(HASHMAP_NAME)
+            except UFOLibError:
+                data = None
             if data:
                 hashmap = ast.literal_eval(data.decode("utf-8"))
             else:
@@ -480,17 +496,14 @@ class UFOFontData:
         if not hashMap:
             return  # no glyphs were processed.
 
-        hasMapKeys = hashMap.keys()
-        hasMapKeys = sorted(hasMapKeys)
         data = ["{"]
-        for gName in hasMapKeys:
+        for gName in sorted(hashMap.keys()):
             data.append("'%s': %s," % (gName, hashMap[gName]))
         data.append("}")
         data.append("")
         data = "\n".join(data)
 
-        writer.writeBytesToPath(os.path.join(DATA_DIRNAME, HASHMAP_NAME),
-                                data.encode("utf-8"))
+        writer.writeData(HASHMAP_NAME, data.encode("utf-8"))
 
     def updateHashEntry(self, glyphName):
         # srcHash has already been set: we are fixing the history list.
@@ -503,6 +516,17 @@ class UFOFontData:
         if AUTOHINT_NAME not in historyList:
             historyList.append(AUTOHINT_NAME)
 
+    def recalcHashEntry(self, glyphName, glyph):
+        hashBefore, historyList = self.hashMap[glyphName]
+
+        hash_pen = HashPointPen(glyph)
+        glyph.drawPoints(hash_pen)
+        hashAfter = hash_pen.getHash()
+
+        if hashAfter != hashBefore:
+            self.hashMap[glyphName] = [hashAfter, historyList]
+            self.hashMapChanged = True
+
     def checkSkipGlyph(self, glyphName, newSrcHash, doAll):
         skip = False
         if self.log_only:
@@ -541,9 +565,10 @@ class UFOFontData:
     def _get_glyphset(self, layer_name=None):
         if layer_name not in self._glyphsets:
             glyphset = None
-            if layer_name is None or layer_name in \
-                    self._reader.getLayerNames():
+            try:
                 glyphset = self._reader.getGlyphSet(layer_name)
+            except UFOLibError:
+                pass
             self._glyphsets[layer_name] = glyphset
         return self._glyphsets[layer_name]
 
@@ -552,7 +577,7 @@ class UFOFontData:
         pen = BezPen(glyph.glyphSet, round_coords)
         glyph.draw(pen)
         if not hasattr(glyph, "width"):
-            glyph.width = 1000
+            glyph.width = 0
         return pen.bez
 
     def _get_or_skip_glyph(self, name, round_coords, doAll):
@@ -578,8 +603,16 @@ class UFOFontData:
         return glyph.width, bez, skip
 
     def getGlyphList(self):
-        glyphset = self._get_glyphset()
-        return sorted(list(glyphset.keys()))
+        glyphOrder = self._reader.readLib().get(PUBLIC_GLYPH_ORDER, [])
+        glyphList = list(self._get_glyphset().keys())
+
+        # Sort the returned glyph list by the glyph order as we depend in the
+        # order for expanding glyph ranges.
+        def key_fn(v):
+            if v in glyphOrder:
+                return glyphOrder.index(v)
+            return len(glyphOrder)
+        return sorted(glyphList, key=key_fn)
 
     @property
     def glyphMap(self):
@@ -651,7 +684,6 @@ class UFOFontData:
             setattr(fdDict, key, value)
 
         otherBlues = self.fontInfo.get("postscriptOtherBlues", [])
-        numBlueValues = len(otherBlues)
 
         if len(otherBlues) > 0:
             i = 0
@@ -786,11 +818,10 @@ class BezPen(BasePen):
 
 
 class HashPointPen(AbstractPointPen):
-    DEFAULT_TRANSFORM = (1, 0, 0, 1, 0, 0)
 
     def __init__(self, glyph):
         self.glyphset = getattr(glyph, "glyphSet", None)
-        self.width = getattr(glyph, "width", 1000)
+        self.width = norm_float(round(getattr(glyph, "width", 0), 9))
         self.data = ["w%s" % self.width]
 
     def getHash(self):
@@ -811,15 +842,16 @@ class HashPointPen(AbstractPointPen):
             pt_type = ""
         else:
             pt_type = segmentType[0]
-        self.data.append("%s%s%s" % (pt_type, repr(pt[0]), repr(pt[1])))
+        self.data.append("%s%s%s" % (pt_type,
+                                     repr(norm_float(round(pt[0], 9))),
+                                     repr(norm_float(round(pt[1], 9)))))
 
     def addComponent(self, baseGlyphName, transformation, identifier=None,
                      **kwargs):
         self.data.append("base:%s" % baseGlyphName)
 
-        for i, v in enumerate(transformation):
-            if transformation[i] != self.DEFAULT_TRANSFORM[i]:
-                self.data.append(str(v))
+        for v in transformation:
+            self.data.append(str(norm_float(round(v, 9))))
 
         self.data.append("w%s" % self.width)
         glyph = self.glyphset[baseGlyphName]
@@ -885,15 +917,22 @@ class HintMask:
 
         if len(self.hList) > 0 or len(self.hstem3List):
             hintset[STEMS_NAME].extend(
-                    makeHintSet(self.hList, self.hstem3List, isH=True))
+                makeHintSet(self.hList, self.hstem3List, isH=True))
 
         if len(self.vList) > 0 or len(self.vstem3List):
             hintset[STEMS_NAME].extend(
-                    makeHintSet(self.vList, self.vstem3List, isH=False))
+                makeHintSet(self.vList, self.vstem3List, isH=False))
 
         return hintset
 
 
+def norm_float(value):
+    """Converts a float (whose decimal part is zero) to integer"""
+    if isinstance(value, float) and value.is_integer():
+        return int(value)
+    return value
+
+
 def makeStemHintList(hintsStem3, isH):
     # In bez terms, the first coordinate in each pair is
     # absolute, second is relative, and hence is the width.
@@ -904,11 +943,7 @@ def makeStemHintList(hintsStem3, isH):
     posList = [op]
     for stem3 in hintsStem3:
         for pos, width in stem3:
-            if pos % 1 == 0:
-                pos = int(pos)
-            if width % 1 == 0:
-                width = int(width)
-            posList.append("%s %s" % (pos, width))
+            posList.append("%s %s" % (norm_float(pos), norm_float(width)))
     return " ".join(posList)
 
 
@@ -921,16 +956,12 @@ def makeHintList(hints, isH):
         if not hint:
             continue
         pos = hint[0]
-        if pos % 1 == 0:
-            pos = int(pos)
         width = hint[1]
-        if width % 1 == 0:
-            width = int(width)
         if isH:
             op = HSTEM_NAME
         else:
             op = VSTEM_NAME
-        hintset.append("%s %s %s" % (op, pos, width))
+        hintset.append("%s %s %s" % (op, norm_float(pos), norm_float(width)))
     return hintset
 
 
@@ -965,12 +996,7 @@ bezToUFOPoint = {
 
 
 def convertCoords(current_x, current_y):
-    x, y = current_x, current_y
-    if x % 1 == 0:
-        x = int(x)
-    if y % 1 == 0:
-        y = int(y)
-    return x, y
+    return norm_float(current_x), norm_float(current_y)
 
 
 def convertBezToOutline(bezString):
@@ -1228,7 +1254,6 @@ def makeHintSet(hints, hintsStem3, isH):
         hintLimit = int((STACK_LIMIT - 2) / 2)
         if numHints >= hintLimit:
             hintsStem3 = hintsStem3[:hintLimit]
-            numHints = hintLimit
         hintset.append(makeStemHintList(hintsStem3, isH))
     else:
         hints.sort()
@@ -1236,7 +1261,6 @@ def makeHintSet(hints, hintsStem3, isH):
         hintLimit = int((STACK_LIMIT - 2) / 2)
         if numHints >= hintLimit:
             hints = hints[:hintLimit]
-            numHints = hintLimit
         hintset.extend(makeHintList(hints, isH))
 
     return hintset
